Index: lib/Nagios/Plugin.pm
===================================================================
--- lib/Nagios/Plugin.pm	(revision 1904)
+++ lib/Nagios/Plugin.pm	(working copy)
@@ -100,6 +100,12 @@
     my $self = shift;
     Nagios::Plugin::Functions::nagios_die(@_, { plugin => $self });
 }
+sub max_state {
+    Nagios::Plugin::Functions::max_state(@_);
+}
+sub max_state_alt {
+    Nagios::Plugin::Functions::max_state_alt(@_);
+}
 
 # Override default shortname accessor to add default
 sub shortname {
@@ -484,6 +490,11 @@
 
 Alias for nagios_die(). Deprecated.
 
+=item max_state, max_state_alt
+
+These are wrapper function for Nagios::Plugin::Functions::max_state and
+Nagios::Plugin::Functions::max_state_alt.
+
 =back
 
 =head2 THRESHOLD METHODS
Index: lib/Nagios/Plugin/Functions.pm
===================================================================
--- lib/Nagios/Plugin/Functions.pm	(revision 1904)
+++ lib/Nagios/Plugin/Functions.pm	(working copy)
@@ -19,11 +19,11 @@
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = (@STATUS_CODES, qw(nagios_exit nagios_die check_messages));
-our @EXPORT_OK = qw(%ERRORS %STATUS_TEXT @STATUS_CODES get_shortname max_state convert);
+our @EXPORT_OK = qw(%ERRORS %STATUS_TEXT @STATUS_CODES get_shortname max_state max_state_alt convert);
 our %EXPORT_TAGS = (
     all => [ @EXPORT, @EXPORT_OK ],
     codes => [ @STATUS_CODES ],
-    functions => [ qw(nagios_exit nagios_die check_messages max_state convert) ],
+    functions => [ qw(nagios_exit nagios_die check_messages max_state max_state_alt convert) ],
 );
 
 use constant OK         => 0;
@@ -70,6 +70,15 @@
 	return UNKNOWN;
 }
 
+sub max_state_alt {
+        return CRITICAL if grep { $_ == CRITICAL } @_;
+        return WARNING if grep { $_ == WARNING } @_;
+        return UNKNOWN if grep { $_ == UNKNOWN } @_;
+        return DEPENDENT if grep { $_ == DEPENDENT } @_;
+        return OK if grep { $_ == OK } @_;
+        return UNKNOWN;
+}
+
 # nagios_exit( $code, $message )
 sub nagios_exit {
     my ($code, $message, $arg) = @_;
@@ -300,6 +309,7 @@
     %STATUS_TEXT
     get_shortname
     max_state
+    max_state_alt
 
 
 =head2 FUNCTIONS
@@ -392,6 +402,18 @@
 Returns the worst state in the array. Order is: CRITICAL, WARNING, OK, UNKNOWN,
 DEPENDENT
 
+The typical usage of max_state is to initialise the state as UNKNOWN and use
+it on the result of various test. If no test were performed successfully the
+state will still be UNKNOWN.
+
+=item max_state_alt(@a)
+
+Returns the worst state in the array. Order is: CRITICAL, WARNING, UNKNOWN,
+DEPENDENT, OK
+
+This is a true definition of a max state (OK last) and should be used if the
+internal tests performed can return UNKNOWN.
+
 =back
 
 =head1 SEE ALSO
